==> foundation-ui-components-1.1.0.tgz: package/src/common/select/stories/NsSelect.stories.tsx <==
import React, { useState } from 'react';
import { ComponentStory, ComponentMeta } from '@storybook/react';
import NsSelect from '../NsSelect';
import NsSelectOption from '../NsSelectOption';

export default {
    title: 'Components/Inputs/NsSelect',
    decorators: [
        (story) => <div style={{ display: 'flex', justifyContent: 'center', alignItems: 'center' }}>{story()}</div>,
    ],
    component: NsSelect,
    argTypes: {
        type: { control: 'select', options: ['unfilled', 'outlined'] },
        disabled: { control: 'boolean' },
        selectBorderColor: {
            control: 'select',
            options: ['primary', 'secondary', 'accentColorA', 'accentColorB', 'accentColorC'],
        },
        placeholder: { control: 'text' },
        closeOnMouseLeave: { control: 'boolean' },
        showListDivider: { control: 'boolean' },
        label: { control: 'text' },
        name: { control: 'text' },
        menuProps:{ control: 'text' },
        reverseArrowControls:{ control: 'boolean' },
        validateOnBlur:{ control: 'boolean' },
        autoComplete: { control: 'text' },
        rules: {control: 'array'},
    },
    parameters: {
        options: [
            { label: 'Alabama', value: 'AL' },
            { label: 'Alaska', value: 'AK' },
            { label: 'Arizona', value: 'AZ' },
            { label: 'Arkansas', value: 'AR' },
            { label: 'California', value: 'CA' },
            { label: 'Colorado', value: 'CO' },
            { label: 'Connecticut', value: 'CT' },
            { label: 'Delaware', value: 'DE' },
            { label: 'District of Columbia', value: 'DC' },
            { label: 'Florida', value: 'FL' },
            { label: 'Georgia', value: 'GA' },
            { label: 'Hawaii', value: 'HI' },
            { label: 'Idaho', value: 'ID' },
            { label: 'Illinois', value: 'IL' },
            { label: 'Indiana', value: 'IN' },
            { label: 'Iowa', value: 'IA' },
            { label: 'Kansas', value: 'KA' },
            { label: 'Kentucky', value: 'KY' },
            { label: 'Louisiana', value: 'LA' },
            { label: 'Maine', value: 'ME' },
            { label: 'Maryland', value: 'MY' },
            { label: 'Massachusetts', value: 'MA' },
            { label: 'Michigan', value: 'MC' },
            { label: 'Minnesota', value: 'MN' },
            { label: 'Mississippi', value: 'MI' },
            { label: 'Missouri', value: 'MO' },
            { label: 'Montana', value: 'MT' },
            { label: 'Nebraska', value: 'NE' },
            { label: 'Nevada', value: 'NA' },
            { label: 'New Hampshire', value: 'NH' },
            { label: 'New Jersey', value: 'NJ' },
            { label: 'New Mexico', value: 'NM' },
            { label: 'New York', value: 'NY' },
            { label: 'North Carolina', value: 'NC' },
            { label: 'North Dakota', value: 'CD' },
            { label: 'Ohio', value: 'OH' },
            { label: 'Oklahoma', value: 'OK' },
            { label: 'Oregon', value: 'OR' },
            { label: 'Pennsylvania', value: 'PA' },
            { label: 'Rhode Island', value: 'RI' },
            { label: 'South Carolina', value: 'SC' },
            { label: 'South Dakota', value: 'SD' },
            { label: 'Tennessee', value: 'TN' },
            { label: 'Texas', value: 'TX' },
            { label: 'Utah', value: 'UT' },
            { label: 'Vermont', value: 'VT' },
            { label: 'Virginia', value: 'VA' },
            { label: 'Washington', value: 'WA' },
            { label: 'West Virginia', value: 'WV' },
            { label: 'Wisconsin', value: 'WN' },
            { label: 'Wyoming', value: 'WY' },
        ],
    },
    args: {
        type: 'outlined',
        disabled: false,
        selectBorderColor: 'primary',
        closeOnMouseLeave: false,
        showListDivider: true,
        selectedValue: '',
        selectedLabel: '',
        label: 'State',
        placeholder:'',
        name:'',
        menuProps:'auto',
        reverseArrowControls: false,
        itemText:'Text',
        itemValue:'Value',
        validateOnBlur: false,
        autoComplete: '',
        rules:[]
    },
} as ComponentMeta<typeof NsSelect>;

export const Select: ComponentStory<typeof NsSelect> = (args, context) => {
    const [selectedLabel, setSelectedLabel] = useState(args.selectedLabel);
    const [selectedValue, setSelectedValue] = useState(args.selectedValue);

    const options = context.parameters.options;
    const handleSelect = (value: string) => {
        setSelectedValue(value);
        options.find((option: any) => {
            if (option.value === value) {
                setSelectedLabel(option.label);
            }
        });
        console.log('Selected:', value);
    };

    return (
        <NsSelect
            {...args}
            selectedValue={selectedValue}
            selectedLabel={selectedLabel}
            onSelect={handleSelect}
            label={args.label}
        >
            {options.map((option: any) => (
                <NsSelectOption key={option.value} value={option.value} label={option.label} />
            ))}
        </NsSelect>
    );
};

==> foundation-ui-components-1.2.0.tgz: package/src/common/select/stories/NsSelect.stories.tsx <==
import React, { useState } from 'react';
import type { Meta, StoryObj } from '@storybook/react';
import NsSelect from '../NsSelect';
import NsSelectOption from '../NsSelectOption';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';

type ComponentType = typeof NsSelect;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/Inputs/NsSelect',
    decorators: [withCenterDecorator],
    component: NsSelect,
    argTypes: {
        type: { control: 'select', options: ['unfilled', 'outlined'] },
        disabled: { control: 'boolean' },
        selectBorderColor: {
            control: 'select',
            options: ['primary', 'secondary', 'accentColorA', 'accentColorB', 'accentColorC'],
        },
        placeholder: { control: 'text' },
        closeOnMouseLeave: { control: 'boolean' },
        showListDivider: { control: 'boolean' },
        label: { control: 'text' },
        name: { control: 'text' },
        menuProps: { control: 'text' },
        reverseArrowControls: { control: 'boolean' },
        validateOnBlur: { control: 'boolean' },
        autoComplete: { control: 'text' },
        rules: { control: 'array' },
        hasArrows: { control: 'boolean' },
    },
    parameters: {
        options: [
            { label: 'Alabama', value: 'AL' },
            { label: 'Alaska', value: 'AK' },
            { label: 'Arizona', value: 'AZ' },
            { label: 'Arkansas', value: 'AR' },
            { label: 'California', value: 'CA' },
            { label: 'Colorado', value: 'CO' },
            { label: 'Connecticut', value: 'CT' },
            { label: 'Delaware', value: 'DE' },
            { label: 'District of Columbia', value: 'DC' },
            { label: 'Florida', value: 'FL' },
            { label: 'Georgia', value: 'GA' },
            { label: 'Hawaii', value: 'HI' },
            { label: 'Idaho', value: 'ID' },
            { label: 'Illinois', value: 'IL' },
            { label: 'Indiana', value: 'IN' },
            { label: 'Iowa', value: 'IA' },
            { label: 'Kansas', value: 'KA' },
            { label: 'Kentucky', value: 'KY' },
            { label: 'Louisiana', value: 'LA' },
            { label: 'Maine', value: 'ME' },
            { label: 'Maryland', value: 'MY' },
            { label: 'Massachusetts', value: 'MA' },
            { label: 'Michigan', value: 'MC' },
            { label: 'Minnesota', value: 'MN' },
            { label: 'Mississippi', value: 'MI' },
            { label: 'Missouri', value: 'MO' },
            { label: 'Montana', value: 'MT' },
            { label: 'Nebraska', value: 'NE' },
            { label: 'Nevada', value: 'NA' },
            { label: 'New Hampshire', value: 'NH' },
            { label: 'New Jersey', value: 'NJ' },
            { label: 'New Mexico', value: 'NM' },
            { label: 'New York', value: 'NY' },
            { label: 'North Carolina', value: 'NC' },
            { label: 'North Dakota', value: 'CD' },
            { label: 'Ohio', value: 'OH' },
            { label: 'Oklahoma', value: 'OK' },
            { label: 'Oregon', value: 'OR' },
            { label: 'Pennsylvania', value: 'PA' },
            { label: 'Rhode Island', value: 'RI' },
            { label: 'South Carolina', value: 'SC' },
            { label: 'South Dakota', value: 'SD' },
            { label: 'Tennessee', value: 'TN' },
            { label: 'Texas', value: 'TX' },
            { label: 'Utah', value: 'UT' },
            { label: 'Vermont', value: 'VT' },
            { label: 'Virginia', value: 'VA' },
            { label: 'Washington', value: 'WA' },
            { label: 'West Virginia', value: 'WV' },
            { label: 'Wisconsin', value: 'WN' },
            { label: 'Wyoming', value: 'WY' },
        ],
    },
    args: {
        type: 'outlined',
        disabled: false,
        selectBorderColor: 'primary',
        closeOnMouseLeave: false,
        showListDivider: true,
        selectedValue: '',
        selectedLabel: '',
        label: 'State',
        placeholder: '',
        name: '',
        menuProps: 'auto',
        reverseArrowControls: false,
        itemText: 'Text',
        itemValue: 'Value',
        validateOnBlur: false,
        autoComplete: '',
        rules: [],
        hasArrows: false,
    },
} as MetaStory;

const AppSelect = (props: any) => {
    const [selectedLabel, setSelectedLabel] = useState(props.selectedLabel);
    const [selectedValue, setSelectedValue] = useState(props.selectedValue);
    const handleSelect = (value: string) => {
        setSelectedValue(value);
        props.options.find((option: any) => {
            if (option.value === value) {
                setSelectedLabel(option.label);
            }
        });
        console.log('Selected:', value);
    };

    return (
        <NsSelect
            {...props}
            selectedValue={selectedValue}
            selectedLabel={selectedLabel}
            onSelect={handleSelect}
            label={props.label}
        >
            {props.options.map((option: any) => (
                <NsSelectOption key={option.value} value={option.value} label={option.label} />
            ))}
        </NsSelect>
    );
};
export const Select: Story = {
    render: (args, context) => {
        const options = context.parameters.options;
        return <AppSelect options={options} {...args} />;
    },
};
